# xlwings Server

xlwings Server adds Python support to Microsoft Excel and Google Sheets without the need of a local Python installation. xlwings Server is self-hosted and runs on any platform that supports Python or Docker, including bare-metal servers, Linux-based VMs, Docker Compose, Kubernetes and serverless products like Azure functions or AWS Lambda.

## Documentation

https://server.xlwings.org

## License

xlwings Server is source-available and dual-licensed under one of the following licenses:

- PolyForm Noncommercial License 1.0.0 (non-commercial use is free)
- xlwings PRO End User License Agreement (commercial use requires a [paid plan](https://www.xlwings.org/pricing))

See https://server.xlwings.org/en/latest/license/
